"""Version information for sage-common package."""

# 独立硬编码版本
__version__ = "0.2.4.30"  # includes merged sage-platform (formerly L2)
__author__ = "IntelliStream Team"
__email__ = "shuhao_zhang@hust.edu.cn"
